@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -46,42 +46,45 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.guard.cron;
 
 import java.util.Calendar;
 import java.util.Date;
-import java.util.Timer;
-import com.openexchange.guard.config.Config;
+import java.util.concurrent.TimeUnit;
+import com.openexchange.exception.OXException;
+import com.openexchange.guard.configuration.GuardConfigurationService;
+import com.openexchange.guard.configuration.GuardProperty;
+import com.openexchange.guard.osgi.Services;
+import com.openexchange.timer.TimerService;
 
 public class Jobs {
 
-    private static Timer timer;
-
     /**
      * Establish Cron jobs for maint.
+     * 
+     * @throws OXException if needed services {@link GuardConfigurationService}, {@link TimerService} are absent
      */
 
-    public Jobs() {
-
+    public Jobs() throws OXException {
+        GuardConfigurationService guardConfigService = Services.getService(GuardConfigurationService.class);
         Calendar calendar = Calendar.getInstance();
         // calendar.add(Calendar.DATE, 1); // Start the next day
-        calendar.set(Calendar.HOUR_OF_DAY, Config.cronHour);
+        calendar.set(Calendar.HOUR_OF_DAY, guardConfigService.getIntProperty(GuardProperty.cronHour));
         calendar.set(Calendar.MINUTE, 0);
         calendar.set(Calendar.SECOND, 0);
         Date time = calendar.getTime();
 
         long dayInterval = 24 * 60 * 60 * 1000; //1 day
-        timer = new Timer();
+        TimerService timer = Services.getService(TimerService.class);
 
         //Job for cleaning the file cache
-        timer.scheduleAtFixedRate(new CleanCache(), time, dayInterval);
+        timer.scheduleAtFixedRate(new CleanCache(), time.getTime(), dayInterval, TimeUnit.DAYS);
 
         //Job for reseting deleted and exposed keys to "not exposed"
-        int exposedKeyDurationInHours = Config.ExposedKeyDurationInHours;
-        if(exposedKeyDurationInHours > 0) {
-            timer.scheduleAtFixedRate(new ResetExposedKeysJob(exposedKeyDurationInHours),
-                                                              time,
-                                                              dayInterval);
+        int exposedKeyDurationInHours = guardConfigService.getIntProperty(GuardProperty.exposedKeyDurationInHours);
+        if (exposedKeyDurationInHours > 0) {
+            timer.scheduleAtFixedRate(new ResetExposedKeysJob(exposedKeyDurationInHours), time.getTime(), dayInterval, TimeUnit.DAYS);
         }
     }
 }
