@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -46,12 +46,13 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.guard.mail;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
-import java.io.UnsupportedEncodingException;
+import java.io.StringReader;
 import java.security.SignatureException;
 import java.util.Iterator;
 import java.util.List;
@@ -60,7 +61,6 @@ import javax.mail.BodyPart;
 import javax.mail.MessagingException;
 import javax.mail.Multipart;
 import javax.mail.Session;
-import javax.mail.internet.InternetHeaders;
 import javax.mail.internet.MimeBodyPart;
 import javax.mail.internet.MimeMessage;
 import javax.mail.internet.MimeMultipart;
@@ -74,40 +74,52 @@ import org.apache.commons.lang.StringUtils;
 import org.bouncycastle.openpgp.PGPException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import com.google.gson.JsonObject;
-import com.openexchange.guard.database.Access;
-import com.openexchange.guard.encr.Crypto;
-import com.openexchange.guard.encr.GuardKeys;
-import com.openexchange.guard.exceptions.BadPasswordException;
-import com.openexchange.guard.mailcreator.Mail;
-import com.openexchange.guard.pgp.PGPUtils;
-import com.openexchange.guard.util.Core;
 
+import com.google.gson.JsonObject;
+import com.openexchange.exception.OXException;
+import com.openexchange.guard.cipher.GuardCipherAlgorithm;
+import com.openexchange.guard.cipher.GuardCipherFactoryService;
+import com.openexchange.guard.cipher.GuardCipherService;
+import com.openexchange.guard.common.servlets.utils.ServletUtils;
+import com.openexchange.guard.exceptions.GuardAuthExceptionCodes;
+import com.openexchange.guard.keys.GuardKeyService;
+import com.openexchange.guard.keys.GuardMasterKeyService;
+import com.openexchange.guard.keys.dao.GuardKeys;
+import com.openexchange.guard.osgi.Services;
+import com.openexchange.guard.pgp.PGPUtils;
+import net.htmlparser.jericho.Source;
 
 public class SignMime {
 
-    private static Logger logger = LoggerFactory.getLogger(SignMime.class);
-    
-    public void processIncomingMime (HttpServletRequest request, HttpServletResponse response) throws Exception {
+    private static Logger LOG = LoggerFactory.getLogger(SignMime.class);
+
+    public void processIncomingMime(HttpServletRequest request, HttpServletResponse response, int userId, int contextId) throws Exception {
         FileItemFactory fif = new DiskFileItemFactory();
         ServletFileUpload sfu = new ServletFileUpload(fif);
-        List files = sfu.parseRequest(request);
-        Iterator iterator = files.iterator(); 
+        List<FileItem> files = sfu.parseRequest(request);
+        Iterator<FileItem> iterator = files.iterator();
         String data = "";
         while (iterator.hasNext()) {
-            FileItem fi = (FileItem) iterator.next();
+            FileItem fi = iterator.next();
             data = fi.getString("UTF-8");
         }
-        int userid = Core.getIntParameter(request, "user");
-        int cid = Core.getIntParameter(request, "context");
-        Access acc = new Access();
-        GuardKeys key = acc.getKeys(userid, cid);
-        Core.sendOK(response, signMime(data, key));
-        
+        GuardKeyService keyService = Services.getService(GuardKeyService.class);
+        GuardKeys key = keyService.getKeys(userId, contextId);
+        try {
+        	ServletUtils.sendHtmlOK(response, signMime(data, key));
+        } catch (OXException ex) {
+        	JsonObject error = new JsonObject();
+        	JsonObject message = new JsonObject();
+        	message.addProperty("message", ex.getLocalizedMessage());
+        	error.add("error", message);
+        	ServletUtils.sendNotAcceptable(response, error.toString());
+        }
+
     }
-    
+
     /**
      * Takes a string mime message and returns signed with new attachment
+     *
      * @param mimemessage
      * @param key
      * @param password
@@ -116,9 +128,9 @@ public class SignMime {
      * @throws IOException
      * @throws SignatureException
      * @throws PGPException
-     * @throws BadPasswordException 
+     * @throws OXException
      */
-    public static String signMime (String mimemessage, GuardKeys key) throws MessagingException, IOException, SignatureException, PGPException, BadPasswordException {
+    public String signMime(String mimemessage, GuardKeys key) throws MessagingException, IOException, SignatureException, PGPException, OXException {
         MimeParser mime = new MimeParser(mimemessage.getBytes("UTF-8"));
         MimeMessage message = mime.getMessage();
         String auth = message.getHeader("X-OX-GUARD-AUTH", "");
@@ -127,18 +139,22 @@ public class SignMime {
         boolean isInline = false;
         String inline = message.getHeader("X-Oxguard-PGPInline", "");
         if (inline != null) {
-            if (inline.toLowerCase().equals("true")) isInline = true;
+            if (inline.toLowerCase().equals("true")) {
+                isInline = true;
+            }
         }
-        String password = Core.decodeRSApassword(auth);
+        String password = decodeRSApassword(auth);
         if (password == null) {
-            logger.info("Bad password for signing");
-            throw (new BadPasswordException ("Bad password"));
+            LOG.info("Bad password for signing");
+            throw GuardAuthExceptionCodes.BAD_PASSWORD.create();
         }
         if (isInline) {
             SignMime sm = new SignMime();
             String signed = sm.SignInline(message, key, password);
-            if (signed != null) return (signed);
-            return (mimemessage);
+            if (signed != null) {
+                return signed;
+            }
+            return mimemessage;
         }
         MimeMultipart mp = mime.getFirstMultipart();
 
@@ -174,12 +190,26 @@ public class SignMime {
         message.setContent(newcontent);
         message.saveChanges();
         // Return the new string
-        return(getMessageContent(message));
-        
+        return getMessageContent(message);
+
     }
-    
+
+    /**
+     * Decode RSA encrypted passwords sent from UI
+     *
+     * @param epass
+     * @return
+     * @throws OXException
+     */
+    public String decodeRSApassword(String epass) throws OXException {
+        GuardCipherService cipherService = Services.getService(GuardCipherFactoryService.class).getCipherService(GuardCipherAlgorithm.RSA);
+        GuardMasterKeyService masterKeyService = Services.getService(GuardMasterKeyService.class);
+        return cipherService.decrypt(epass, masterKeyService.getMasterKey().getPrivateKey());
+    }
+
     /**
      * Sign a message inline format, should be plaintext
+     *
      * @param mime
      * @param key
      * @param password
@@ -187,15 +217,15 @@ public class SignMime {
      * @throws IOException
      * @throws MessagingException
      */
-    private String SignInline (MimeMessage mime, GuardKeys key, String password) throws IOException, MessagingException {
+    private String SignInline(MimeMessage mime, GuardKeys key, String password) throws IOException, MessagingException {
         Object content = mime.getContent();
-        if (content instanceof Multipart || content instanceof MimeMultipart)  {
+        if (content instanceof Multipart || content instanceof MimeMultipart) {
             // This is experimental and not working well.  HTML failing, and known limitation of Inline
-            MimeMultipart newcontent = signParts ((MimeMultipart) content, key, password);
+            MimeMultipart newcontent = signParts((MimeMultipart) content, key, password);
             mime.setContent(newcontent);
             mime.saveChanges();
             String data = getMessageContent(mime);
-            return(data);
+            return (data);
         } else {
             // Sign plaintext email
             if (content instanceof String) {
@@ -204,16 +234,16 @@ public class SignMime {
                 mime.setContent(signed, mime.getContentType());
                 mime.saveChanges();
                 String data = getMessageContent(mime);
-                return(data);
+                return (data);
             }
         }
         return (null);
-        
+
     }
 
-    
     /**
-     * Expiremental.  Not yet working or supported.  Signing multipart alternative.  HTML failing
+     * Expiremental. Not yet working or supported. Signing multipart alternative. HTML failing
+     *
      * @param mp
      * @param key
      * @param password
@@ -221,7 +251,7 @@ public class SignMime {
      * @throws MessagingException
      * @throws IOException
      */
-    private MimeMultipart signParts (MimeMultipart mp, GuardKeys key, String password) throws MessagingException, IOException { 
+    private MimeMultipart signParts(MimeMultipart mp, GuardKeys key, String password) throws MessagingException, IOException {
         int count = mp.getCount();
         String mtype = mp.getContentType();
         if (mtype != null) {
@@ -230,59 +260,67 @@ public class SignMime {
             if (mtype.contains("/")) {
                 mtype = mtype.substring(mtype.indexOf("/") + 1);
             }
-        } else mtype = "alternative";
+        } else {
+            mtype = "alternative";
+        }
         MimeMultipart newMpart = new MimeMultipart(mtype);
         for (int i = 0; i < count; i++) {
             MimeBodyPart bp = (MimeBodyPart) mp.getBodyPart(i);
             Object content = bp.getContent();
-            if (content instanceof Multipart || content instanceof MimeMultipart)  {
-                content = signParts ((MimeMultipart) content, key, password);
+            if (content instanceof Multipart || content instanceof MimeMultipart) {
+                content = signParts((MimeMultipart) content, key, password);
             }
             if (content instanceof String) {
                 if (bp.getContentType().contains("text")) {
                     String type = bp.getContentType();
                     boolean html = type.contains("html");
-                    String [] ctypes = type.split(";");
+                    String[] ctypes = type.split(";");
                     String encoding = "UTF-8";
                     for (String ctype : ctypes) {
                         if (ctype.contains("charset=")) {
                             int cindex = ctype.indexOf("=");
-                            encoding = ctype.substring(cindex+1);
+                            encoding = ctype.substring(cindex + 1);
                         }
                     }
-                    bp.setText(signMessage((String) content, key, password, html), encoding); 
+                    bp.setText(signMessage((String) content, key, password, html), encoding);
                     bp.setHeader("Content-Type", type);
                 }
 
             }
             newMpart.addBodyPart(bp);
         }
-        return(newMpart);
+        return (newMpart);
     }
-    
+
     // Sign the message and return wrapped text
-    private String signMessage (String message, GuardKeys key, String password, boolean html) {
+    private String signMessage(String message, GuardKeys key, String password, boolean html) {
         try {
-            if (html) message = Mail.getPlainText(message);
-            message = normalize((String) message);
+            if (html) {
+                message = getPlainText(message);
+            }
+            message = normalize(message);
             StringBuilder sig = new StringBuilder();
-            if (html) sig.append("<pre>\r\n");
+            if (html) {
+                sig.append("<pre>\r\n");
+            }
             sig.append("-----BEGIN PGP SIGNED MESSAGE-----\r\nHash: SHA256\r\n\r\n");
             sig.append(message);
             sig.append("\r\n");
-            String signature = signString (message, key, password);
+            String signature = signString(message, key, password);
             sig.append(signature);
-            if (html) sig.append("</pre>");
-        return (sig.toString());
+            if (html) {
+                sig.append("</pre>");
+            }
+            return (sig.toString());
         } catch (Exception ex) {
-            logger.error("Error signing inline message", ex);
-            return(message);
+            LOG.error("Error signing inline message", ex);
+            return (message);
         }
     }
-    
-    private String signString (String message, GuardKeys key, String password) throws SignatureException, IOException, PGPException {
+
+    private String signString(String message, GuardKeys key, String password) throws SignatureException, IOException, PGPException, OXException {
         PGPUtils util = new PGPUtils();
-        ByteArrayInputStream in = new ByteArrayInputStream (message.getBytes("UTF-8"));
+        ByteArrayInputStream in = new ByteArrayInputStream(message.getBytes("UTF-8"));
         ByteArrayOutputStream out = new ByteArrayOutputStream();
         util.createDetachedSignature(in, out, key, password, true);
         String signature = new String(out.toByteArray(), "UTF-8");
@@ -290,26 +328,28 @@ public class SignMime {
         in.close();
         return (signature);
     }
-    
+
     /**
      * Get the content of the multipart for signing
+     *
      * @param mp
      * @return
      * @throws IOException
      * @throws MessagingException
      */
-    private static String getPartContent (MimeMultipart mp) throws IOException, MessagingException {
+    private String getPartContent(MimeMultipart mp) throws IOException, MessagingException {
         ByteArrayOutputStream out = new ByteArrayOutputStream();
         // we need to wrap in message to get full writeout of the mimepart contents witht he content-type header
         MimeMessage msg = new MimeMessage(Session.getInstance(new Properties()));
         msg.setContent(mp);
-        msg.writeTo(out, new String []{"Message-ID", "MIME-Version"});
+        msg.writeTo(out, new String[] { "Message-ID", "MIME-Version" });
         out.close();
         return (new String(out.toByteArray(), "UTF-8"));
     }
-    
+
     /**
      * Remove any whitespaces and normalize with \r\n after each line
+     *
      * @param content
      * @return
      */
@@ -321,19 +361,29 @@ public class SignMime {
         }
         return (sb.toString());
     }
-    
-    private static String getMessageContent (MimeMessage message) throws IOException, MessagingException {
+
+    private String getMessageContent(MimeMessage message) throws IOException, MessagingException {
         ByteArrayOutputStream out = new ByteArrayOutputStream();
         message.writeTo(out);
         out.close();
-        return(out.toString());
+        return (out.toString());
     }
-    
-    private static String getMessageContentForSigning (MimeMessage message) throws IOException, MessagingException {
+
+    private String getMessageContentForSigning(MimeMessage message) throws IOException, MessagingException {
         ByteArrayOutputStream out = new ByteArrayOutputStream();
-        message.writeTo(out, new String []{"Message-ID", "MIME-Version"});
+        message.writeTo(out, new String[] { "Message-ID", "MIME-Version" });
         out.close();
-        return(out.toString());
+        return (out.toString());
+    }
+
+    private String getPlainText(String html) {
+        try {
+            StringReader sr = new StringReader(html);
+            Source src = new Source(sr);
+            return (src.getRenderer().toString());
+        } catch (Exception e) {
+            LOG.error("Error converting HTML to plaintext ", e);
+            return (html);
+        }
     }
-    
 }
